---
name: 'Feature request'
about: Suggest an idea for improving Pseudopeople
title: '[FEAT] <title>'
labels: 'enhancement'
assignees: ''
---

### Is your proposal related to a problem?
<!--
  Provide a clear and concise description of what the problem is. For example, "I'm always frustrated when..."
-->



### Describe the solution you'd like
<!--
  Provide a clear and concise description of what you want to happen.
-->



### Describe alternatives you've considered
<!--
  Let us know about other solutions you've tried or researched.
-->



### Additional context
<!--
  Is there anything else you can add about the proposal? You might want to link to related issues here, if you haven't already.
-->

